"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const operators_1 = require("rxjs/operators");
const apis_1 = require("../infrastructure/apis");
const runtime_1 = require("./runtime");
const ContractClientHttp_1 = require("./ContractClientHttp");
const models_1 = require("./models");
const readline = require('readline');
class ContractReplicatorHttp extends ContractClientHttp_1.ContractClientHttp {
    /**
     * Constructor
     * @param url
     */
    constructor(configuration) {
        super(configuration);
        this.contractReplicator = new apis_1.ContractReplicatorApi(new runtime_1.Configuration(configuration));
    }
    invites() {
        /*
        wget -q -O - http://localhost:6468/api/v1/contract/invites
        {"Invite":{"drive":"baegaajaiaqjcbfwppizwbuajbfxvybu4i7zf5qwp5azdkgecjmklbpp7rxvccj4e","owner":"080412200eb448d07c7ccb312989ac27aa052738ff589e2f83973f909b506b450dc5c4e2","duration":295704,"space":66,"payedReplicas":6,"minReplicators":5,"percentApprovers":80,"billingPrice":123,"billingPeriod":444}}
        {"Invite":{"drive":"baegaajaiaqjcbzlrl4mpuaiel2cl76hfhxyhkvsbsjpps6wobx4yutsizknm5xlt","owner":"080412200eb448d07c7ccb312989ac27aa052738ff589e2f83973f909b506b450dc5c4e2","duration":295704,"space":66,"payedReplicas":6,"minReplicators":5,"percentApprovers":80,"billingPrice":123,"billingPeriod":444}}
        */
        return rxjs_1.from(this.contractReplicator.invitesRaw())
            .pipe(operators_1.flatMap(response => {
            return new rxjs_1.Observable(subscriber => {
                const rl = readline.createInterface({
                    input: response.response.body,
                    crlfDelay: Infinity
                });
                rl.on('line', (line) => {
                    const parsed = JSON.parse(line);
                    subscriber.next(models_1.InviteWrapFromJSON(parsed).invite);
                });
                rl.on('close', () => {
                    subscriber.complete();
                });
                return function unsubscribe() {
                    response.abortController.abort();
                };
            });
        }));
    }
    accept(drive) {
        return rxjs_1.from(this.contractReplicator.accept({ argDrive: drive }));
    }
    accepted() {
        return rxjs_1.from(this.contractReplicator.acceptedRaw())
            .pipe(operators_1.flatMap(response => {
            return new rxjs_1.Observable(subscriber => {
                const rl = readline.createInterface({
                    input: response.response.body,
                    crlfDelay: Infinity
                });
                rl.on('line', (line) => {
                    const parsed = JSON.parse(line);
                    subscriber.next(models_1.ContractWrapFromJSON(parsed).contract);
                });
                rl.on('close', () => {
                    subscriber.complete();
                });
                return function unsubscribe() {
                    response.abortController.abort();
                };
            });
        }));
    }
}
exports.ContractReplicatorHttp = ContractReplicatorHttp;
//# sourceMappingURL=ContractReplicatorHttp.js.map