"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const apis_1 = require("../infrastructure/apis");
const runtime_1 = require("./runtime");
class DriveFsHttp {
    /**
     * Constructor
     * @param url
     */
    constructor(configuration) {
        this.driveFsRoutesApi = new apis_1.DriveFSApi(new runtime_1.Configuration(configuration));
    }
    add(cid, dstPath, body, flush) {
        return rxjs_1.from(this.driveFsRoutesApi.driveAdd({
            argDrive: cid,
            argDst: dstPath,
            flush: flush,
            body: body
        }).then(cidWrap => cidWrap.id));
    }
    cp(cid, srcPath, dstPath, flush) {
        return rxjs_1.from(this.driveFsRoutesApi.driveCp({
            argDrive: cid,
            argSrc: srcPath,
            argDst: dstPath,
            flush: flush
        }));
    }
    flush(cid) {
        return rxjs_1.from(this.driveFsRoutesApi.driveFlush({
            argDrive: cid
        }));
    }
    getAsText(cid, path) {
        return rxjs_1.from(this.driveFsRoutesApi.driveGetAsText({
            argDrive: cid,
            argSrc: path
        }));
    }
    getAsBlob(cid, path) {
        return rxjs_1.from(this.driveFsRoutesApi.driveGetAsBlob({
            argDrive: cid,
            argSrc: path
        }));
    }
    getAsResponse(cid, path) {
        return rxjs_1.from(this.driveFsRoutesApi.driveGetAsResponse({
            argDrive: cid,
            argSrc: path
        }));
    }
    fileAsText(cid, cidFile) {
        return rxjs_1.from(this.driveFsRoutesApi.driveFileAsText({
            argDrive: cid,
            argFileCid: cidFile
        }));
    }
    fileAsBlob(cid, cidFile) {
        return rxjs_1.from(this.driveFsRoutesApi.driveFileAsBlob({
            argDrive: cid,
            argFileCid: cidFile
        }));
    }
    fileAsResponse(cid, cidFile) {
        return rxjs_1.from(this.driveFsRoutesApi.driveFileAsResponse({
            argDrive: cid,
            argFileCid: cidFile
        }));
    }
    ls(cid, path) {
        return rxjs_1.from(this.driveFsRoutesApi.driveLs({
            argDrive: cid,
            argSrc: path
        }).then(statListWrap => statListWrap.list));
    }
    mkDir(cid, path, flush) {
        return rxjs_1.from(this.driveFsRoutesApi.driveMkdir({
            argDrive: cid,
            argSrc: path,
            flush: flush
        }).then(_ => { }));
    }
    mv(cid, srcPath, dstPath, flush) {
        return rxjs_1.from(this.driveFsRoutesApi.driveMv({
            argDrive: cid,
            argSrc: srcPath,
            argDst: dstPath,
            flush: flush
        }).then(_ => { }));
    }
    rm(cid, path, flush) {
        return rxjs_1.from(this.driveFsRoutesApi.driveRm({
            argDrive: cid,
            argSrc: path,
            flush: flush
        }).then(_ => { }));
    }
    stat(cid, path) {
        return rxjs_1.from(this.driveFsRoutesApi.driveStat({
            argDrive: cid,
            argSrc: path
        }).then(statWrap => statWrap.stat));
    }
}
exports.DriveFsHttp = DriveFsHttp;
//# sourceMappingURL=DriveFsHttp.js.map