"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const rxjs_1 = require("rxjs");
const apis_1 = require("../infrastructure/apis");
const runtime_1 = require("./runtime");
class SuperContractHttp {
    /**
     * Constructor
     * @param url
     */
    constructor(configuration) {
        this.superContractRoutesApi = new apis_1.SuperContractApi(new runtime_1.Configuration(configuration));
    }
    deploy(cid, driveFilePath) {
        return rxjs_1.from(this.superContractRoutesApi.deploy({
            argDrive: cid,
            argSrc: driveFilePath
        }).then(cidResultWrap => cidResultWrap.result));
    }
    ls(cid) {
        return rxjs_1.from(this.superContractRoutesApi.lsSC({
            argDrive: cid
        }).then(cidListWrap => cidListWrap.ids));
    }
    get(cid) {
        return rxjs_1.from(this.superContractRoutesApi.getSC({
            argScId: cid
        }).then(superContractWrap => superContractWrap.superContract));
    }
    execute(cid, gas, functionName, params = []) {
        return rxjs_1.from(this.superContractRoutesApi.execute({
            argScId: cid,
            argGas: gas,
            argFuncName: functionName,
            argArgsArray: params
        }));
    }
    executions() {
        return rxjs_1.from(this.superContractRoutesApi.executions().then(executionsWrap => executionsWrap.ids));
    }
    results(cid) {
        return rxjs_1.from(this.superContractRoutesApi.results({
            argTxId: cid
        }).then(resultsWrap => resultsWrap.results));
    }
    deactivate(cid) {
        return rxjs_1.from(this.superContractRoutesApi.deactivate({
            argScId: cid
        }));
    }
}
exports.SuperContractHttp = SuperContractHttp;
//# sourceMappingURL=SuperContractHttp.js.map